/**
 * Stream Date View
 * @author Dominik Geng
 * @copyright 2018 Dominik Geng
 * @license Apache-2.0
 */
export declare class StreamDataView {
    /**
     * Creates a new instance of StreamDataView.
     * e.g. from the string of toByteString()
     * @param str Byte string like '48 65 6C 6C 6F'
     */
    static fromByteString(str: string): StreamDataView;
    private offset;
    private view;
    private littleEndian;
    /**
     * A buffer walker.
     * @param buffer Array buffer.
     * @param bigEndian Use big endian for numbers. (default: little endian)
     */
    constructor(buffer: ArrayBuffer | number, bigEndian?: boolean);
    /**
     * Returns the array buffer of the data view.
     * @return The buffer of this data view.
     */
    getBuffer(): ArrayBuffer;
    /**
     * Moves the offset relative in a direction.
     * @param length Positive or negative number byte length.
     */
    skip(length: number): void;
    /**
     * Moves the offset to zero.
     */
    resetOffset(): void;
    /**
     * Returns the current offset.
     * @return Offset
     */
    getOffset(): number;
    /**
     * Sets a new offset to an absolute position.
     * @param offset New offset (starts from zero)
     */
    setOffset(offset: number): void;
    /**
     * Reads a 8-bit singed integer.
     * @param offset Buffer offset.
     */
    getInt8(offset: number): number;
    /**
     * Reads a 8-bit unsinged integer.
     * @param offset Buffer offset.
     */
    getUint8(offset: number): number;
    /**
     * Reads the next 8-bit singed integer from current offset.
     */
    getNextInt8(): number;
    /**
     * Reads the next 8-bit unsinged integer from curret offset.
     */
    getNextUint8(): number;
    /**
     * Reads a 16-bit singed integer.
     * @param offset Buffer offset.
     */
    getInt16(offset: number): number;
    /**
     * Reads a 16-bit unsinged integer.
     * @param offset Buffer offset.
     */
    getUint16(offset: number): number;
    /**
     * Reads the next 16-bit singed integer.
     */
    getNextInt16(): number;
    /**
     * Reads the next 16-bit unsinged integer.
     */
    getNextUint16(): number;
    /**
     * Reads a 32-bit singed integer.
     * @param offset Buffer offset.
     */
    getInt32(offset: number): number;
    /**
     * Reads a 32-bit unsinged integer.
     * @param offset Buffer offset.
     */
    getUint32(offset: number): number;
    /**
     * Reads the next 32-bit singed integer.
     */
    getNextInt32(): number;
    /**
     * Reads the next 32-bit unsinged integer.
     */
    getNextUint32(): number;
    /**
     * Reads a float. (32-bit, signed)
     * @param offset Buffer offset.
     */
    getFloat32(offset: number): number;
    /**
     * Reads a double. (64-bit signed)
     * @param offset Buffer offset.
     */
    getFloat64(offset: number): number;
    /**
     * Reads the next float. (32-bit, signed)
     */
    getNextFloat32(): number;
    /**
     * Reads the next double. (64-bit, signed)
     */
    getNextFloat64(): number;
    /**
     * Writes a 8-bit signed integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setInt8(offset: number, value: number): void;
    /**
     * Writes a 8-bit unsigned integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setUint8(offset: number, value: number): void;
    /**
     * Writes the next 8-bit signed integer to the buffer.
     * @param value Value to write.
     */
    setNextInt8(value: number): void;
    /**
     * Writes the next 8-bit unsigned integer to the buffer.
     * @param value Value to write.
     */
    setNextUint8(value: number): void;
    /**
     * Writes a 16-bit signed integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setInt16(offset: number, value: number): void;
    /**
     * Writes a 16-bit unsigned integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setUint16(offset: number, value: number): void;
    /**
     * Writes the next 16-bit signed integer to the buffer.
     * @param value Value to write.
     */
    setNextInt16(value: number): void;
    /**
     * Writes the next 16-bit unsigned integer to the buffer.
     * @param value Value to write.
     */
    setNextUint16(value: number): void;
    /**
     * Writes a 32-bit signed integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setInt32(offset: number, value: number): void;
    /**
     * Writes a 32-bit unsigned integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setUint32(offset: number, value: number): void;
    /**
     * Writes the next 32-bit signed integer to the buffer.
     * @param value Value to write.
     */
    setNextInt32(value: number): void;
    /**
     * Writes the next 32-bit unsigned integer to the buffer.
     * @param value Value to write.
     */
    setNextUint32(value: number): void;
    /**
     * Writes a float to the buffer. (32-bit, signed)
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setFloat32(offset: number, value: number): void;
    /**
     * Writes a double to the buffer. (64-bit, signed)
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setFloat64(offset: number, value: number): void;
    /**
     * Writes the next float to the buffer. (32-bit, signed)
     * @param value Value to write.
     */
    setNextFloat32(value: number): void;
    /**
     * Writes the next double to the buffer. (64-bit, signed)
     * @param value Value to write.
     */
    setNextFloat64(value: number): void;
    /**
     * Reads an array of bytes.
     * @param offset Buffer offset.
     * @param length Buffer length.
     */
    getBytes(offset: number, length?: number): Uint8Array;
    /**
     * Reads the next array of bytes.
     * @param length Buffer length. (default: remaining length)
     */
    getNextBytes(length?: number): Uint8Array;
    /**
     * Writes a byte array to the buffer.
     * @param offset Buffer offset.
     * @param data Byte array to write.
     */
    setBytes(offset: number, data: Uint8Array): void;
    /**
     * Writes the next byte array to the buffer.
     * @param data Byte array to write.
     */
    setNextBytes(data: Uint8Array): void;
    /**
     * Reads a string from the buffer.
     * @param offset Buffer offset.
     * @param length Buffer length.
     * @param utf8 Use utf-8 encoding. (default: ascii)
     * @param untilTerminator Only returns the string until zero terminator.
     */
    getString(offset: number, length: number, utf8?: boolean, untilTerminator?: boolean): string;
    /**
     * Returns a string from the buffer.
     * @param length Buffer length.
     * @param utf8 Use utf-8 encoding. (default: ascii)
     * @param untilTerminator Only returns the string until zero terminator. Does not affect the offset shifting.
     */
    getNextString(length: number, utf8?: boolean, untilTerminator?: boolean): string;
    /**
     * Sets a string to the buffer.
     * @param offset Buffer offset.
     * @param data Data to write.
     * @param utf8 Use utf-8. (default: ascii)
     * @param length Optional fixed length write on buffer.
     */
    setString(offset: number, data: string, utf8?: boolean, length?: number): number;
    /**
     * Sets a string to the buffer.
     * @param data Data to write.
     * @param utf8 Use uff-8. (default: ascii)
     * @param length Optional fixed length write on buffer.
     */
    setNextString(data: string, utf8?: boolean, length?: number): void;
    /**
     * Converts the buffer to a pretty print byte string.
     * Like '48 65 6C 6C 6F'
     */
    toByteString(): string;
    /**
     * Converts the buffer to a text string.
     * @param utf8 Handle it as UTF8 string otherwise ASCII.
     */
    toTextString(utf8?: boolean): string;
    /**
     * Parses a string of bytes like '48 65 6C 6C 6F'.
     * Also see the method 'toByteString'.
     * @param str Byte string.
     */
    fromByteString(str: string): void;
}
